@@ -282,6 +282,14 @@ class SqlAlchemyProxy:
                     raise exception
         log.debug(self.run, 'Database tables created')
 
+    @Method
+    def flush(self):
+        self.session.flush()
+
+    @Method
+    def rollback(self):
+        self.session.rollback()
+
     @Method
     def commit(self):
         self.session.commit()
